@@ -32,18 +32,28 @@ add_repeat.simple_ensemble <- function(x, rep, ...) {
     attr(x, "best_metric") <- attr(rep, "best_metric")
     attr(x, "metrics") <- attr(rep, "metrics")
     new_rep <- "rep_01"
-  } else { # check that the new rep is compatible
+  } else {
+    # check that the new rep is compatible
     # check that metrics match
     if (attr(x, "best_metric") != attr(rep, "best_metric")) {
-      stop("the best metric in the repeated ensemble differs from the repeat being added")
+      stop(
+        "the best metric in the repeated ensemble differs ",
+        "from the repeat being added"
+      )
     }
     if (all(attr(x, "metrics") != attr(rep, "metrics"))) {
-      stop("the metrics in the repeated ensemble differ from the repeat being added")
+      stop(
+        "the metrics in the repeated ensemble differ from ",
+        "the repeat being added"
+      )
     }
     rep_number <- max(as.numeric(substr(x$rep_id, 5, nchar(x$rep_id)))) + 1
     new_rep <- paste0("rep_", sprintf("%02d", rep_number))
     if (!setequal(unique(x$wflow_id), rep$wflow_id)) {
-      stop("the models in the repeated ensemble differ from the repeat being added")
+      stop(
+        "the models in the repeated ensemble differ ",
+        "from the repeat being added"
+      )
     }
   }
   rep <- rep %>% dplyr::mutate(rep_id = new_rep, .before = "wflow_id")
